# Generated by Django 2.2.1 on 2019-05-27 10:39

import django.utils.crypto
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('mailauth_user', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='emailuser',
            name='session_salt',
            field=models.CharField(default=django.utils.crypto.get_random_string, editable=False, max_length=12),
        ),
    ]
